# Task


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**last_status** | [**TaskStatus**](TaskStatus.md) |  | [readonly] 
**task_type** | [**TaskType**](TaskType.md) |  | 
**active** | **bool** |  | [optional] [default to True]
**task_type_display** | **str** |  | [readonly] 
**created_dt** | **datetime** |  | [readonly] 
**device** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


